@@ -10,7 +10,7 @@ use Travel::Status::DE::EFA::Stop;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '3.11';
+our $VERSION = '3.12';
 
 Travel::Status::DE::EFA::Departure->mk_ro_accessors(
 	qw(countdown datetime delay destination is_cancelled key line lineref mot
@@ -177,10 +177,11 @@ sub id {
 
 	return $self->{id} = sprintf( '%s@%d(%s)%d',
 		$self->stateless =~ s{ }{}gr,
-		scalar $self->route_pre
-		? ( $self->route_pre )[0]->id_num
+		scalar $self->route_pre ? ( $self->route_pre )[0]->id_num
 		: $self->stop_id_num,
-		$self->sched_datetime->strftime('%Y%m%d'),
+		( scalar $self->route_pre and ( $self->route_pre )[0]->sched_dep )
+		? ( $self->route_pre )[0]->sched_dep->strftime('%Y%m%dT%H:%M')
+		: $self->sched_datetime->strftime('%Y%m%dT%H:%M'),
 		$self->key );
 }
 
@@ -303,7 +304,7 @@ departure received by Travel::Status::DE::EFA
 
 =head1 VERSION
 
-version 3.11
+version 3.12
 
 =head1 DESCRIPTION
 
